@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2016-06-02'; # DATE
-our $VERSION = '0.38'; # VERSION
+our $DATE = '2016-12-27'; # DATE
+our $VERSION = '0.39'; # VERSION
 
 use 5.010001;
 use strict;
@@ -71,9 +71,8 @@ my %pericmd_attrs = (
     },
     url => {
         summary => 'Program URL',
-        schema => 'str*',
+        schema => 'riap::url*',
         pos => 0,
-        'x.schema.entity' => 'riap_url',
     },
     extra_urls_for_version => {
         summary => 'More URLs to show version for --version',
@@ -104,14 +103,14 @@ $SPEC{gen_inline_pericmd_script} = {
     description => <<'_',
 
 The goal of this module is to let you create a CLI script from a Riap
-function/metadata. This is like what `Perinci::CmdLine::Lite` or
-`Perinci::CmdLine::Classic` does, except that the generated CLI script will have
+function/metadata. This is like what <pm:Perinci::CmdLine::Lite> or
+<pm:Perinci::CmdLine::Classic> does, except that the generated CLI script will have
 the functionalities inlined so it only need core Perl modules and not any of the
 `Perinci::CmdLine::*` or other modules to run (excluding what modules the Riap
 function itself requires).
 
 It's useful if you want a CLI script that is even more lightweight (in terms of
-startup overhead or dependencies) than the one using `Perinci::CmdLine::Lite`.
+startup overhead or dependencies) than the one using <pm:Perinci::CmdLine::Lite>.
 
 So to reiterate, the goal of this module is to create a Perinci::CmdLine-based
 script which only requires core modules, and has as little startup overhead as
@@ -127,7 +126,7 @@ Currently it only supports a subset of features compared to other
 
 As an alternative to this module, if you are looking to reduce dependencies, you
 might also want to try using `depak` to fatpack/datapack your
-`Perinci::CmdLine::Lite`-based script.
+<pm:Perinci::CmdLine::Lite>-based script.
 
 _
     args_rels => {
@@ -929,7 +928,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.38 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2016-06-02.
+This document describes version 0.39 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2016-12-27.
 
 =head1 SYNOPSIS
 
@@ -990,14 +989,14 @@ values are subroutines' source codes.
 Generate inline Perinci::CmdLine CLI script.
 
 The goal of this module is to let you create a CLI script from a Riap
-function/metadata. This is like what C<Perinci::CmdLine::Lite> or
-C<Perinci::CmdLine::Classic> does, except that the generated CLI script will have
+function/metadata. This is like what L<Perinci::CmdLine::Lite> or
+L<Perinci::CmdLine::Classic> does, except that the generated CLI script will have
 the functionalities inlined so it only need core Perl modules and not any of the
 C<Perinci::CmdLine::*> or other modules to run (excluding what modules the Riap
 function itself requires).
 
 It's useful if you want a CLI script that is even more lightweight (in terms of
-startup overhead or dependencies) than the one using C<Perinci::CmdLine::Lite>.
+startup overhead or dependencies) than the one using L<Perinci::CmdLine::Lite>.
 
 So to reiterate, the goal of this module is to create a Perinci::CmdLine-based
 script which only requires core modules, and has as little startup overhead as
@@ -1009,7 +1008,7 @@ C<Perinci::CmdLine::*> implementations:
 =over
 
 =item * Only support local Riap URL (e.g. C</Foo/bar>, not
-C<http://example.org/Foo/bar>);
+CLL<http://example.org/Foo/bar>);
 
 =item * No subcommands support yet;
 
@@ -1017,7 +1016,7 @@ C<http://example.org/Foo/bar>);
 
 As an alternative to this module, if you are looking to reduce dependencies, you
 might also want to try using C<depak> to fatpack/datapack your
-C<Perinci::CmdLine::Lite>-based script.
+L<Perinci::CmdLine::Lite>-based script.
 
 This function is not exported by default, but exportable.
 
@@ -1163,7 +1162,7 @@ Currently does nothing, provided only for compatibility with Perinci::CmdLine::B
 
 Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
-=item * B<url> => I<str>
+=item * B<url> => I<riap::url>
 
 Program URL.
 
